'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const path = require('path');
const fs = require('fs');
const sharp = require('sharp');
const fg = require('fast-glob');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

const path__default = /*#__PURE__*/_interopDefaultLegacy(path);
const fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
const sharp__default = /*#__PURE__*/_interopDefaultLegacy(sharp);
const fg__default = /*#__PURE__*/_interopDefaultLegacy(fg);

const getFileName = (path2) => {
  return path2.replace(/(.*\/)*([^.]+).*/gi, "$2");
};
const getRelativePathName = (path2) => {
  const p = path2.split("/");
  if (p[0] === ".")
    p.shift();
  if (p.length >= 2)
    p.shift();
  const f = p[p.length - 1].split(".");
  if (f.length >= 2)
    f.pop();
  p[p.length - 1] = f.join(".");
  const pathName = p.join("/");
  p.pop();
  return [pathName, p.join("/")];
};
const batSharp = async (options) => {
  const {
    inputArr = [],
    format = "png",
    outputPath,
    outputConfig = {},
    maintainRelativePath = true
  } = options || {};
  if (!outputPath || !inputArr?.length || !format)
    return;
  const entries = await fg__default(inputArr, { dot: true });
  console.log("input file list: ", entries);
  const isExist = fs__default.existsSync(path__default.normalize(outputPath));
  if (!isExist)
    fs__default.mkdirSync(outputPath);
  let isAllSucc = true;
  for (const filePath of entries) {
    let targetPathName = "";
    if (maintainRelativePath) {
      const [pathName, pathWithoutName] = getRelativePathName(filePath);
      targetPathName = path__default.join(outputPath, `${pathName}.${format}`);
      const targetPath = path__default.join(outputPath, pathWithoutName);
      if (!fs__default.existsSync(path__default.normalize(targetPath)))
        fs__default.mkdirSync(targetPath);
    } else {
      targetPathName = path__default.join(outputPath, `${getFileName(filePath)}.${format}`);
    }
    sharp__default(filePath)[format](outputConfig).toFile(`${targetPathName}`, (err) => {
      if (err)
        isAllSucc = false;
    });
  }
  if (isAllSucc)
    console.log(`Task finished! Please check the path ${outputPath}.`);
};

exports.batSharp = batSharp;
